bleAddress property

  1. @Deprecated('Use bleName instead')
  2. @override
String? get bleAddress
override

The BLE address of this device.

The format of the BLE address is platform-specific. On Android, it is typically a MAC address of the form 00:04:79:00:0F:4D. On iOS, it is typically be a UUID string on the form E2C56DB5-DFFB-48D2-B060-D0F5A71096E0.

Returns null if unknown. Typically, the BLE address is only known after pairing with a specific BLE device.

Implementation

@Deprecated('Use bleName instead')
@override
String? get bleAddress => bleName;
  1. @Deprecated('Use bleName instead')
  2. @override
set bleAddress (String? address)
override

The BLE address of this device.

The format of the BLE address is platform-specific. On Android, it is typically a MAC address of the form 00:04:79:00:0F:4D. On iOS, it is typically be a UUID string on the form E2C56DB5-DFFB-48D2-B060-D0F5A71096E0.

Returns null if unknown. Typically, the BLE address is only known after pairing with a specific BLE device.

Implementation

@Deprecated('Use bleName instead')
@override
set bleAddress(String? address) => bleName = address;