ESenseSensor class

Holds information about an eSense button pressed event.

This data is a 1:1 mapping of the eSense SensorEvent event.

Inheritance
Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

ESenseSensor({required String deviceName, DateTime? timestamp, int? packetIndex, List<int>? accel, List<int>? gyro})
ESenseSensor.fromJson(Map<String, dynamic> json)
factory
ESenseSensor.fromSensorEvent({required String deviceName, required SensorEvent event})
factory

Properties

$type ↔ String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
accel ↔ List<int>?
3-elements array with X, Y and Z axis for accelerometer
getter/setter pair
dataType → DataType
The type of this data as a DataType.
no setterinherited
deviceName ↔ String
The name of eSense device that generated this event.
getter/setter pairinherited
fromJsonFunction → Function
The function which can convert a JSON string to an object of this type.
no setteroverride
gyro ↔ List<int>?
3-elements array with X, Y and Z axis for gyroscope
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonType → String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setteroverride
packetIndex ↔ int?
Sequential number of sensor packets. The eSense device don't have a clock, so this index reflect the order of reading.
getter/setter pair
recordId → String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ DateTime
Timestamp of this event.
getter/setter pairinherited

Methods

equivalentTo(Data other) → bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited